didPop method
Called when the current route has been popped off.
Implementation
@override
void didPop() {
// TODO: implement didPop
super.didPop();
print('didPop');
}
Called when the current route has been popped off.
@override
void didPop() {
// TODO: implement didPop
super.didPop();
print('didPop');
}