BaseView class abstract
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BaseView
- Implementers
Constructors
- BaseView.builder({Key? key, dynamic arguments, ScreenModePackage screenMode = ScreenModePackage.FULL_SCREEN, BottomMenuPackage bottomMenu = BottomMenuPackage.NONE, bool isScroll = true, Function? onCallback, String? screenTitle, double? productNameTextSize, Color? productNameTextColor, double? productAmountTextSize, Color? productAmountTextColor, Color? cardViewBgColor, double? cardViewTextSize, Color? cardViewTextColor, Color? cardViewTextHintColor, double? confirmButtonTextSize, Color? confirmButtonTextColor})
-
const
Properties
- arguments → dynamic
-
final
- bottomMenu → BottomMenuPackage
-
final
- cardViewBgColor → Color?
-
final
- cardViewTextColor → Color?
-
final
- cardViewTextHintColor → Color?
-
final
- cardViewTextSize → double?
-
final
- confirmButtonTextColor → Color?
-
final
- confirmButtonTextSize → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isScroll → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onCallback → Function?
-
final
- productAmountTextColor → Color?
-
final
- productAmountTextSize → double?
-
final
- productNameTextColor → Color?
-
final
- productNameTextSize → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenMode → ScreenModePackage
-
final
- screenTitle → String?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → BaseState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited