WidgetHelper class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
getInkWellWidget({required Widget child, required Function onTap})
→ Widget
-
-
setColorButton({required String buttonText, required Function onTapCalled, required BuildContext context, required Color colorbg, dynamic colortext, double width = 200, double height = 50, double borderWidth = 1, double borderRadius = 10, TextStyle? textStyle})
→ Widget
-